# Copyright (c) 2022 CESNET
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

from .ext import NRDocumentsAppExtension

__version__ = "1.0.8"

__all__ = ('__version__', 'NRDocumentsAppExtension')
